@@ -13,6 +13,7 @@ raise_signal = getattr(
     signal, "raise_signal", lambda signum: os.kill(os.getpid(), signum)
 )
 
+
 # Inherit from KeyboardInterrupt to avoid a traceback from asyncio.
 class SignalInterrupt(KeyboardInterrupt):
     def __init__(self, signum):
@@ -81,7 +82,6 @@ try:
     RETURNCODE_WRITE_FAILED = 2
 
     class FifoWriter(AbstractPollTask):
-
         __slots__ = ("buf", "fifo", "_fd")
 
         def _start(self):
@@ -128,7 +128,6 @@ try:
                 self._fd = None
 
     class EbuildIpc:
-
         # Timeout for each individual communication attempt (we retry
         # as long as the daemon process appears to be alive).
         _COMMUNICATE_RETRY_TIMEOUT = 15  # seconds
@@ -151,7 +150,6 @@ try:
                 return False
 
         def communicate(self, args):
-
             # Make locks quiet since unintended locking messages displayed on
             # stdout could corrupt the intended output of this program.
             portage.locks._quiet = True
@@ -165,10 +163,7 @@ try:
         def _timeout_retry_msg(self, start_time, when):
             time_elapsed = time.time() - start_time
             portage.util.writemsg_level(
-                portage.localization._(
-                    "ebuild-ipc timed out %s after %d seconds," + " retrying...\n"
-                )
-                % (when, time_elapsed),
+                f"ebuild-ipc timed out {when} after {time_elapsed} seconds, retrying...\n",
                 level=logging.ERROR,
                 noiselevel=-1,
             )
@@ -209,7 +204,6 @@ try:
             return fifo_writer.wait()
 
         def _receive_reply(self, input_fd):
-
             start_time = time.time()
 
             pipe_reader = PipeReader(
@@ -237,7 +231,6 @@ try:
             retval = 2
 
             if not buf:
-
                 portage.util.writemsg_level(
                     f"ebuild-ipc: {portage.localization._('read failed')}\n",
                     level=logging.ERROR,
@@ -245,7 +238,6 @@ try:
                 )
 
             else:
-
                 try:
                     reply = pickle.loads(buf)
                 except SystemExit:
@@ -258,7 +250,6 @@ try:
                     )
 
                 else:
-
                     (out, err, retval) = reply
 
                     if out:
@@ -270,7 +261,6 @@ try:
             return retval
 
         def _communicate(self, args):
-
             if not self._daemon_is_alive():
                 self._no_daemon_msg()
                 return 2
@@ -297,8 +287,7 @@ try:
 
             if retval != os.EX_OK:
                 portage.util.writemsg_level(
-                    "ebuild-ipc: %s: %s\n"
-                    % (msg, portage.localization._("subprocess failure: %s") % retval),
+                    f"ebuild-ipc: {msg}: subprocess failure: {retval}\n",
                     level=logging.ERROR,
                     noiselevel=-1,
                 )
